Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(987)

Unified Diff: media/base/video_frame.h

Issue 591313008: Add support for Rec709 color space videos in software YUV convert path. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Clean up some bad rebasing... Created 6 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: media/base/video_frame.h
diff --git a/media/base/video_frame.h b/media/base/video_frame.h
index ca2a2e28e0e05ffbcca8166c6994075abe167754..1527f685e8294c092588d4ed3f8ccc894c175a39 100644
--- a/media/base/video_frame.h
+++ b/media/base/video_frame.h
@@ -63,7 +63,8 @@ class MEDIA_EXPORT VideoFrame : public base::RefCountedThreadSafe<VideoFrame> {
YV12J = 7, // JPEG color range version of YV12
NV12 = 8, // 12bpp 1x1 Y plane followed by an interleaved 2x2 UV plane.
YV24 = 9, // 24bpp YUV planar, no subsampling.
- FORMAT_MAX = YV24, // Must always be equal to largest entry logged.
+ YV12HD = 10, // Rec709 "HD" color space version of YV12
+ FORMAT_MAX = YV12HD, // Must always be equal to largest entry logged.
};
// Returns the name of a Format as a string.

Powered by Google App Engine
This is Rietveld 408576698